<!DOCTYPE TS><TS>
<context>
    <name>ArtefactAction</name>
    <message>
        <source>Add</source>
        <translation type="unfinished">Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished">Bearbeiten</translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished">Entfernen</translation>
    </message>
</context>
<context>
    <name>AskCost</name>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AskDiversificationList</name>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished">Entfernen</translation>
    </message>
</context>
<context>
    <name>BuildingAction</name>
    <message>
        <source>Add</source>
        <translation type="unfinished">Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished">Bearbeiten</translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished">Entfernen</translation>
    </message>
</context>
<context>
    <name>DecorationEffect</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>DialogArtefactAction</name>
    <message>
        <source>Action type: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Characteristic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modification type: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameter: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Value: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>DialogBuildingAction</name>
    <message>
        <source>Action type: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Time Lord</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defense</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Knowledge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maxmove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TechPoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MaxTechPoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Experience</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artefact</source>
        <translation type="unfinished">Artefakt</translation>
    </message>
    <message>
        <source>Unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resource</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Resource</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Elementary Action: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Param: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coeff: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>DialogEffect</name>
    <message>
        <source>Effect type: </source>
        <translation>Effektart: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Effect value: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCost</name>
    <message>
        <source>Ok</source>
        <translation type="unfinished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>EditCreature</name>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attack: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defense: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Health: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Move: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dist Attack: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Min Damages: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max Damages: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Morale: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luck: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation type="unfinished">Bild: </translation>
    </message>
    <message>
        <source>X Offset: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y Offset: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTroop</name>
    <message>
        <source>Race : </source>
        <translation>Rasse: </translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Art: </translation>
    </message>
    <message>
        <source>Number : </source>
        <translation>Anzahl: </translation>
    </message>
</context>
<context>
    <name>MapDispositionEditor</name>
    <message>
        <source>Free</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Occupied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Door</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewBaseDialog</name>
    <message>
        <source>Buildings</source>
        <translation>Gebäude</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Effect &apos;</source>
        <translation>Effekt &apos;</translation>
    </message>
    <message>
        <source>&apos; with param </source>
        <translation>&apos; mit Parameter</translation>
    </message>
    <message>
        <source>Action: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charac </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> modify by </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> elementary </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionArtefact</name>
    <message>
        <source>Artefact</source>
        <translation>Artefakt</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name: </translation>
    </message>
    <message>
        <source>Position: </source>
        <translation>Position:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Symbol:</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Gegenstand:</translation>
    </message>
</context>
<context>
    <name>SectionBase</name>
    <message>
        <source> Base </source>
        <translation>Basis</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Population: </source>
        <translation>Bevölkerung:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Vorschau</translation>
    </message>
    <message>
        <source> Base : %d/%d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Res Cost: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Growth: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loss: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preview inside</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionBuilding</name>
    <message>
        <source>Building</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Picture: </source>
        <translation>Bild: </translation>
    </message>
    <message>
        <source>Number Frames: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animation Freq.: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionCreature</name>
    <message>
        <source>Race</source>
        <translation>Rasse</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source> Creature </source>
        <translation>Kreatur</translation>
    </message>
    <message>
        <source> Race : %d/%d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Creature : %d/%d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Creature : %d/??</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionDecoration</name>
    <message>
        <source>Decoration</source>
        <translation type="obsolete">Verzierung</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Info: </source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Image: </source>
        <translation>Bild:</translation>
    </message>
    <message>
        <source>Decoration group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoration item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionExperience</name>
    <message>
        <source>List of required experience to gain for accessing the next level:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionGeneral</name>
    <message>
        <source>Fog of war</source>
        <translation type="obsolete">Fog of war</translation>
    </message>
    <message>
        <source>Number of unit/lord</source>
        <translation>Anzahl an Einheit/Lord</translation>
    </message>
    <message>
        <source>Logo (200x180): </source>
        <translation>Logo(200x180):</translation>
    </message>
    <message>
        <source>Vision management: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionGround</name>
    <message>
        <source>Tiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coef: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team</source>
        <translation type="obsolete">Team</translation>
    </message>
    <message>
        <source>Tile </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionInsideBuilding</name>
    <message>
        <source> Building </source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Cost: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintenance cost: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Building : %d/%d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Params: </source>
        <translation type="unfinished">Parameter:</translation>
    </message>
    <message>
        <source>Not yet used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Building</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Castle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prod Creature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Market</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionLord</name>
    <message>
        <source>Lord</source>
        <translation>Fürst</translation>
    </message>
    <message>
        <source>Photo: </source>
        <translation>Portrait: </translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Symbol:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Name: </translation>
    </message>
    <message>
        <source>Category : </source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Race : </source>
        <translation type="obsolete">Rasse:</translation>
    </message>
    <message>
        <source>Attack : </source>
        <translation>Angriff:</translation>
    </message>
    <message>
        <source>Defense : </source>
        <translation>Verteidigung:</translation>
    </message>
    <message>
        <source>Power : </source>
        <translation>Macht:</translation>
    </message>
    <message>
        <source>Knowledge : </source>
        <translation>Wissen:</translation>
    </message>
    <message>
        <source>MaxMoves : </source>
        <translation>Bewegungsreichweite:</translation>
    </message>
    <message>
        <source>Vision : </source>
        <translation>Sichtreichweite:</translation>
    </message>
    <message>
        <source> (Race: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionLordCategory</name>
    <message>
        <source>Lord Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished">Beschreibung:</translation>
    </message>
    <message>
        <source>Race: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution of Attack skill (weight): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution of Defense skill (weight): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution of Power skill (weight): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution of Knowledge skill (weight): </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionMachine</name>
    <message>
        <source>War Machine</source>
        <translation>Kriegsgerät</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Param (1): </source>
        <translation>Parameter(1):</translation>
    </message>
    <message>
        <source>Params: </source>
        <translation>Parameter:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Symbol:</translation>
    </message>
    <message>
        <source>Item: </source>
        <translation>Gegenstand:</translation>
    </message>
</context>
<context>
    <name>SectionRessource</name>
    <message>
        <source>Ressource</source>
        <translation>Ressource</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Icon: </source>
        <translation>Symbol:</translation>
    </message>
    <message>
        <source>Small icon: </source>
        <translation>Kleines Symbol:</translation>
    </message>
</context>
<context>
    <name>SectionSelector</name>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Artefacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Teams</translation>
    </message>
    <message>
        <source>Bases</source>
        <translation>Basen</translation>
    </message>
    <message>
        <source>Buildings</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Creatures</source>
        <translation>Kreaturen</translation>
    </message>
    <message>
        <source>Decorations</source>
        <translation>Verzierungen</translation>
    </message>
    <message>
        <source>Grounds</source>
        <translation>Gelände</translation>
    </message>
    <message>
        <source>Lords</source>
        <translation>Fürsten</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <source>War Machines</source>
        <translation>Kriegsmaschinerie</translation>
    </message>
    <message>
        <source>Lord Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Levels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionTeam</name>
    <message>
        <source>Team</source>
        <translation>Team</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <source>Flag: </source>
        <translation>Flagge:</translation>
    </message>
</context>
<context>
    <name>SelectionWidget</name>
    <message>
        <source>None</source>
        <translation>Keines</translation>
    </message>
</context>
<context>
    <name>ThemeInterface</name>
    <message>
        <source>Theme editor for &apos;Attal - Lords of Doom&apos;</source>
        <translation>Szenarienset-Editor für &quot;Attal-Lord of Doom&quot;</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusleiste</translation>
    </message>
    <message>
        <source>New theme</source>
        <translation>Neues Szenarienset</translation>
    </message>
    <message>
        <source>Open theme</source>
        <translation>Öffne Szenarienset</translation>
    </message>
    <message>
        <source>Save theme</source>
        <translation>Speichere Szenarienset</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;New theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
